@@ -21,7 +21,6 @@ a single value.
 
 Notably, the set of steps available at any point may depend on the
 execution to date.
-
 """
 
 
@@ -42,14 +41,15 @@ from hypothesis._settings import Verbosity
 from hypothesis._settings import settings as Settings
 from hypothesis.reporting import report, verbose_report, current_verbosity
 from hypothesis.strategies import just, lists, builds, one_of, runner, \
-    integers
+    tuples, integers, fixed_dictionaries
 from hypothesis.vendor.pretty import CUnicodeIO, RepresentationPrinter
 from hypothesis.internal.reflection import proxies, nicerepr
 from hypothesis.internal.conjecture.data import StopTest
-from hypothesis.internal.conjecture.utils import integer_range
+from hypothesis.internal.conjecture.utils import integer_range, \
+    calc_label_from_name
 from hypothesis.searchstrategy.strategies import SearchStrategy
-from hypothesis.searchstrategy.collections import TupleStrategy, \
-    FixedKeysDictStrategy
+
+STATE_MACHINE_RUN_LABEL = calc_label_from_name('another state machine step')
 
 
 class TestCaseProperty(object):  # pragma: no cover
@@ -99,7 +99,6 @@ def run_state_machine_as_test(state_machine_factory, settings=None):
     state_machine_factory is anything which returns an instance of
     GenericStateMachine when called with no arguments - it can be a class or a
     function. settings will be used to control the execution of the test.
-
     """
     try:
         breaker = find_breaking_runner(state_machine_factory, settings)
@@ -135,7 +134,6 @@ class GenericStateMachine(object):
 
     And if this ever produces an error it will shrink it down to a small
     sequence of example choices demonstrating that.
-
     """
 
     def steps(self):
@@ -151,7 +149,6 @@ class GenericStateMachine(object):
         """Print a step to the current reporter.
 
         This is called right before a step is executed.
-
         """
         self.step_count = getattr(self, u'step_count', 0) + 1
         report(u'Step #%d: %s' % (self.step_count, nicerepr(step)))
@@ -161,7 +158,6 @@ class GenericStateMachine(object):
         state.
 
         Does nothing by default
-
         """
         pass
 
@@ -213,7 +209,6 @@ class StateMachineRunner(object):
     """A StateMachineRunner is a description of how to run a state machine.
 
     It contains values that it will use to shape the examples.
-
     """
 
     def __init__(self, data, n_steps):
@@ -234,7 +229,7 @@ class StateMachineRunner(object):
             while True:
                 if steps >= self.n_steps:
                     stopping_value = 0
-                self.data.start_example()
+                self.data.start_example(STATE_MACHINE_RUN_LABEL)
                 if not cu.biased_coin(self.data, stopping_value):
                     self.data.stop_example()
                     break
@@ -301,7 +296,6 @@ def rule(targets=(), target=None, **kwargs):
     invocation. If their value is a Bundle then values that have previously
     been produced for that bundle will be provided, if they are anything else
     it will be turned into a strategy and values from that will be provided.
-
     """
     if target is not None:
         targets += (target,)
@@ -356,7 +350,6 @@ def precondition(precond):
 
     This is better than using assume in your rule since more valid rules
     should be able to be run.
-
     """
     def decorator(f):
         @proxies(f)
@@ -400,7 +393,6 @@ def invariant():
             @invariant()
             def is_nonzero(self):
                 assert self.state != 0
-
     """
     def accept(f):
         existing_invariant = getattr(f, INVARIANT_MARKER, None)
@@ -436,7 +428,6 @@ class RuleBasedStateMachine(GenericStateMachine):
     from bundles (or just from normal strategies) and push data onto
     bundles. At any given point a random applicable rule will be
     executed.
-
     """
 
     _rules_per_class = {}
@@ -543,10 +534,9 @@ class RuleBasedStateMachine(GenericStateMachine):
                         break
                 converted_arguments[k] = v
             if valid:
-                strategies.append(TupleStrategy((
-                    just(rule),
-                    FixedKeysDictStrategy(converted_arguments)
-                ), tuple))
+                strategies.append(tuples(
+                    just(rule), fixed_dictionaries(converted_arguments)
+                ))
         if not strategies:
             raise InvalidDefinition(
                 u'No progress can be made from state %r' % (self,)
